#
# spec file for package ipmitool (Version 1.8.11)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           ipmitool
BuildRequires:  openssl-devel readline-devel
Url:            http://ipmitool.sourceforge.net/
Summary:        Utility for IPMI Control
Version:        1.8.11
Release:        5.6.36
License:        BSD 3-Clause
Group:          System/Management
Source:         http://heanet.dl.sourceforge.net/sourceforge/%{name}/%{name}-%{version}.tar.bz2
Patch:          compile-fixes
Patch2:         fix-crash-in-sdr-elist
Patch3:         fix_file_permissions.patch
Patch5:         ekanalyzer_fix_wrong_type_comparison.patch
Patch6:         increase_possible_fw_file_size.patch
Patch7:         fwum_enhance_output.patch
Patch8:         lan_fix_return_value.patch
Patch9:         sdradd_close_file_handle.patch
Patch10:        add-dell-oem

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains a utility for interfacing with devices that
support the Intelligent Platform Management Interface specification. 
IPMI is an open standard for machine health, inventory, and remote
power control.

This utility can communicate with IPMI-enabled devices through either a
kernel driver such as OpenIPMI or over the RMCP LAN protocol defined in
the IPMI specification.  IPMIv2 adds support for encrypted LAN
communications and remote Serial-over-LAN functionality.

It provides commands for reading the Sensor Data Repository (SDR) and
displaying sensor values, displaying the contents of the System Event
Log (SEL), printing Field Replaceable Unit (FRU) information, reading
and setting LAN configuration, and chassis power control.



%prep
%setup -q
%patch -p1
%patch2 -p1
%patch3 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1

%build
touch INSTALL NEWS
autoreconf -fiv
%configure --with-pic 
%{__make} %{?jobs:-j%jobs}

%install
make DESTDIR=$RPM_BUILD_ROOT install
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/ipmitool

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README
%{_bindir}/*
%{_sbindir}/*
%{_datadir}/ipmitool
#%{_datadir}/doc/packages/ipmitool/*
%doc %{_mandir}/man1/*
%doc %{_mandir}/man8/*

%changelog
* Wed Sep 29 2010 duwe@suse.de
- Backport from SLE11 SP1 to SLE10 SP4, add dell OEM [FATE#309695]
* Fri May 29 2009 kukuk@suse.de
- Backport from SLE11 to SLE10 SP3 [FATE#306228]
* Tue Oct 14 2008 crrodriguez@suse.de
- fix implicit-fortify-decl errors
* Fri Sep 26 2008 duwe@suse.de
- fix ugly code and sloppy programming found by RPMlint
* Fri Sep 12 2008 duwe@suse.de
- update to version 1.8.10 as requested in FATE#304431
  + remove fixes now in mainline
* Thu Jan 17 2008 duwe@suse.de
- Fix bnc#298222 and bnc#144023 (arg checking and POH scaling)
* Thu Mar  8 2007 duwe@suse.de
- add new compile fixes
* Wed Mar  7 2007 duwe@suse.de
- update to 1.8.9, fixing ipmievd crashing.
  This was requesten in Bug#246456
* Fri Oct 13 2006 duwe@suse.de
- update to today's CVS state
  * might fix SoL issues (Fate #30911)
* Tue Oct 10 2006 duwe@suse.de
- update to 1.8.8 mainly various fixes:
  version 1.8.8
  * Fix segfaults in sensor data repository list
  * Fix ipmievd to open interface before daemonizing
  * Fix IPMIv1.5 authtype NONE to ignore supplied password
  * Fix cipher suite display bug in lan print
  * Fix typo in IPMIv2 SOL output when sending break
  * Fix improper LUN handling with Tyan SOL
  * Add LUN support to OpenIPMI interface
  * Add support for Kontron OEM commands
  * Update to Kontron Firmware Update command
  version 1.8.7
  * Remove nuclear clause from license
  * Add Sun OEM command for blades
  * Increase argument size for raw commands in shell/exec
  * Fix handling of LUNs for LAN interfaces
  * Add IPMIv2 SOL loopback test
  * Add support for IBM OEM SEL messages
  * Disable file paranoia checks on read files by default
  * Support IPMIv2 SOL on older Intel boxes
  * Display message and exit if keepalive fails during SOL
  * Add support for setting VLAN id and priority
  * Add support for FreeBSD OpenIPMI-compatible driver
  * Add support for IPMIv2 Firmware Firewall
  * Fix gcc4 compile warnings
  * Make ipmievd generate pidfile
  * Add initscripts for ipmievd
* Mon May 29 2006 kukuk@suse.de
- Fix type conversion bug in ipmi_pef.c [#173658]
* Fri May 26 2006 schwab@suse.de
- Add readline-devel to BuildRequires to enable shell command.
- Fix use of channel_info bitfield.
- Fix byte swapping.
* Mon Feb 13 2006 kukuk@suse.de
- Update to ipmitool 1.8.6 [#134708,#131823]
  - Fix memory corruption when sending encrypted SOL traffic
  - Add keepalive timer to IPMIv2 SOL sessions
  - Raise privilege level after creating IPMIv2 session
  - Add support for settable SOL escape character with -e option
  - Add support for Kg BMC key for IPMIv2 authentication with -k option
  - Add support for Tyan IPMIv1.5 SOL with tsol command
  - Add support for PICMG devices
  - Add support for OEM SEL event parsing
  - Add support for command bridging over lan and lanplus interfaces
  - New 'chassis selftest' command
  - Many bufxies and patches from contributors
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 schwab@suse.de
- Don't strip binaries.
* Mon Sep 19 2005 kukuk@suse.de
- Fix missing return value
* Thu Aug  4 2005 kukuk@suse.de
- Initial release (FeatureID #165)
